@@ -8,7 +8,7 @@ use Mango::BSON ':bson';
 use MangoX::Queue::Delay;
 use DateTime::Tiny;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # A logger
 has 'log' => sub { Mojo::Log->new->level('error') };
@@ -78,20 +78,24 @@ sub get_options {
 
     return {
         query => {
-            '$or' => [{
-                status => {
-                    '$in' => ref($self->{pending_status}) eq 'ARRAY' ? $self->{pending_status} : [ $self->{pending_status} ],
-                },
-                '$or' => [ { processing => 0 }, { processing => undef } ],
+            '$and' => [{
+                '$or' => [ { delay_until => undef }, { delay_until => { '$lt' => time } } ],
             },{
-                status => $self->{processing_status},
-                processing => {
-                    '$lt' => time - $self->timeout,
-                }
-            }],
-            attempt => {
-                '$lte' => $self->retries + 1,
-            },
+                '$or' => [{
+                    status => {
+                        '$in' => ref($self->{pending_status}) eq 'ARRAY' ? $self->{pending_status} : [ $self->{pending_status} ],
+                    },
+                    '$or' => [ { processing => 0 }, { processing => undef } ],
+                },{
+                    status => $self->{processing_status},
+                    processing => {
+                        '$lt' => time - $self->timeout,
+                    }
+                }],
+                attempt => {
+                    '$lte' => $self->retries + 1,
+                },
+            }]
         },
         sort => bson_doc( # Sort by priority, then in order of creation
             'priority' => 1,
@@ -132,6 +136,8 @@ sub enqueue {
         processing => 0,
     };
 
+    $db_job->{delay_until} = $args{delay_until} if $args{delay_until};
+
     if($callback) {
         return $self->collection->insert($db_job => sub {
             my ($collection, $error, $oid) = @_;
@@ -736,6 +742,12 @@ Wait for a job to enter a certain status.
         # ...
     };
 
+=head1 FUTURE JOBS
+
+Jobs can be queued in advance by setting a delay_until attribute:
+
+    enqueue $queue delay_until => (time + 20), "job name";
+
 =head1 ERRORS
 
 Errors are reported by MangoX::Queue using callbacks and L<Mojo::EventEmitter>
